pub enum FontFeatureValuesBlockType {
Swash,
Stylistic,
Ornaments,
Annotation,
CharacterVariant,
Styleset,
}Expand description
Keeps the information about block type like @swash, @styleset etc.
Variants
Swash
A @swash blocksck. Specifies a feature name that will work with the swash() functional notation of font-variant-alternates.
Stylistic
A @stylistic block. Specifies a feature name that will work with the annotation() functional notation of font-variant-alternates.
Ornaments
A @ornaments block. Specifies a feature name that will work with the ornaments() ] functional notation of font-variant-alternates.
Annotation
A @annotation block. Specifies a feature name that will work with the stylistic() functional notation of font-variant-alternates.
CharacterVariant
A @character-variant block. Specifies a feature name that will work with the styleset() functional notation of font-variant-alternates. The value can be a pair.
Styleset
A @styleset block. Specifies a feature name that will work with the character-variant() functional notation of font-variant-alternates. The value can be a list.
Implementations